(function () {
  'use strict';

  angular
    .module('starter')
    .controller('PayCtrl', MainCtrl);

  function MainCtrl($scope, RouteData, $ionicHistory, $httpFactory, $state, $ionicSlideBoxDelegate, $ionicLoading, $rootScope, $ionicPopup) {
    {
      initData();
      initProductList();
      $scope.navBack = navBack;
      $scope.changePayType = changePayType;
      $scope.payType = _app.payType_wechat;
      $scope.pay = pay;
      $scope.toShop = toShop;
      $scope.shareApp = shareApp;
      var payHandle_success = false;
      var payHandle_cancel = false;
      qrcode();
    }

    function initData() {
      $scope.productPay = RouteData.productPay;       //初始化付款产品
      $scope.paySelectType = 1; //默认家长代付1，自己支付为2
    }

    //家长扫码支付
    function qrcode() {
      var productCode = $scope.productPay.content[0].productCode;
      var userId = _appv.currentUser.userId;
      $httpFactory.order.order_qrcode(productCode, userId).then(function (res) {
        if (res.data.message.match("已经购买")) {
          $ionicLoading.show({template: res.data.message});
          return;
        }
        $scope.orderInfo = res.data.object;
        if (res.data.result == 0 && res.data.object.status != 1) {
          setTimeout(function () {
            // 安卓9.0初始化二维码，采用的画布样式
            // 安卓8初始化二维码，采用img样式
            // 所以这里初始化时候，带上width,height设置
            $scope.myQrCode = new QRCode(document.getElementById("qrcode"), {
              text: res.data.object.jsapiDto.code_url,
              width: 130,
              height: 130
            });
          }, 200);
        }
      });
      $scope.checkOrder = function () {
        orderCheck($scope.orderInfo.code);// 订单校验
      }
    }

    function navBack() {
      $ionicHistory.goBack();
    }

    function changePayType(type) {
      $scope.payType = type;
    }

    function initProductList() {
      var level, knowId, userId, type;
      level = 0;
      userId = _appv.currentUser.userId;
      type = 2;
      $httpFactory.product.productList(level, null, userId, type).then(function (res) {
        if (res.data.result == 0) {
          var productList = res.data.object;
          var noPayList = [];      //未购买的产品
          $scope.page = [[]];           //分页后的数据
          var k = 0;
          for (var i = 0; i < productList.length; i++) {
            productList[i].status == 1 && noPayList.push(productList[i]);
          }
          for (var i = 0; i < noPayList.length; i++) {
            if (i != 0 && i % 3 == 0) {
              k++;
              $scope.page[k] = [];
            }
            $scope.page[k].push(noPayList[i]);
          }
          $ionicSlideBoxDelegate.update();
        }
      });
    }

    function pay(type) {
      var data = {
        token: _appv.token,
        content: JSON.stringify($scope.productPay.content)
      };

      switch (type) {
        case _app.payType_alipay:      //支付宝支付
          $ionicLoading.show({template: '处理中...', duration: 3000});
          aliPay(data);
          break;
        case _app.payType_wechat:      //微信支付
          $ionicLoading.show({template: '处理中...', duration: 3000});
          wechatPay(data);
          break;
        case _app.payType_qq:          //qq钱包支付
          $ionicLoading.show({template: '处理中...', duration: 3000});
          qqPay(data);
          break;
      }
    }

    /**
     * 校验订单
     * @param orderCode
     */
    function orderCheck(orderCode) {
      $httpFactory.order.order_query(orderCode).then(function (request) {
        if (request.data.result == 0) {
          if (request.data.object.status == 1) {// 状态，0待支付，1已支付，2异常|失败，3作废
            afterPay();
            /** 订单支付完成,回调业务 **/
          } else {
            $ionicLoading.hide();
            // $ionicLoading.show({template: '订单尚未支付完成...', duration: 2000});// TODO 微信偶然会自动取消,所以暂不提示
          }
        } else {
          $ionicLoading.hide();
          $ionicLoading.show({template: request.message});
        }
      })
    }


    function afterPay() {
      //购买课件返回
      if ($scope.productPay.productType == _app.orderType_exp) {
        $rootScope.refresherExp();
        $state.go('menu.main.exp');
      }
      //购买套餐返回
      if ($scope.productPay.productType == _app.orderType_book) {
        RouteData.myTrolley = [];
        $rootScope.refresherExp();
        $state.go('menu.main.exp');
      }
      //购买视频返回
      if ($scope.productPay.productType == _app.orderType_video) {
        $rootScope.refresherVideo();
        // $state.go('menu.main.videoLive');
        $state.go('menu.videoInfo');
      }
      //购买直播返回
      if ($scope.productPay.productType == _app.orderType_live) {
        $rootScope.refresherLive();
        $state.go('menu.main.videoLive');
      }
    }

    function aliPay(data) {
      //生成订单
      $httpFactory.order.alipay(_appv.currentUser.userId, data).then(function (res) {
        if (!res.data.object) {
          $ionicLoading.show({template: res.data.message});
          return;
        }
        var aliDto = res.data.object.aliDto;
        //调用支付宝支付
        window.alipay && window.alipay.pay(aliDto, function (successResults) {
          console.log(successResults);
          $ionicLoading.show({template: '支付成功'});
          payHandle_success = true;
          afterPay();
        }, function (errorResults) {
          console.log(errorResults);
          payHandle_cancel = true;
          // alert('支付失败!');
        });

        // 启动页面再激活监听
        document.addEventListener("resume", function resumeListener() {
          // alert('resume payHandle_cancel:'+payHandle_cancel+' payHandle_success:'+payHandle_success);
          setTimeout(function () {
            if (!payHandle_success) {
              orderCheck(res.data.object.code);// 订单校验
            }
          }, 1000);
          document.removeEventListener("resume", resumeListener);// 删除当前事件监听
        }, false);

      }, function (res) {
        $ionicLoading.show({template: res.data.message});
      });
    }

    function wechatPay(data) {
      $httpFactory.order.wechatPay(_appv.currentUser.userId, data).then(function (response) {
        if (!response.data.object) {
          $ionicLoading.show({template: response.data.message});
          return;
        }
        var dto = response.data.object.dto;
        // alert("dto数据: " + JSON.stringify(dto));
        window.Wechat && window.Wechat.sendPaymentRequest(dto, function () {
          console.log("Success");
          $ionicLoading.show({template: '支付成功'});
          payHandle_success = true;
          afterPay();
          // success_pay();
        }, function (reason) {
          // alert("Failed: " + reason);
          console.log("Failed:", reason);
          payHandle_cancel = true;
          // alert('支付失败!');
        });

        // 启动页面再激活监听
        document.addEventListener("resume", function resumeListener() {
          // alert('resume payHandle_cancel:'+payHandle_cancel+' payHandle_success:'+payHandle_success);
          setTimeout(function () {
            if (!payHandle_success) {
              orderCheck(response.data.object.code);// 订单校验
            }
          }, 1000);
          document.removeEventListener("resume", resumeListener);// 删除当前事件监听
        }, false);
      });
    }

    function qqPay(data) {
      $httpFactory.order.qqPay(_appv.currentUser.userId, data).then(function (res) {
        if (res.data.result == 0) {
          var dto = res.data.object.qpayDto;
          QPay.mqqPay(dto, function (res) {
            if (res.isSuccess || res.match('成功')) {
              $ionicLoading.show({template: '支付成功,若仍显示未订购请返回等待几秒后刷新', duration: 3000});
              payHandle_success = true;
              // alert("支付成功："+JSON.stringify(res));
              afterPay();
            }
          }, function (res) {
            // alert("支付失败:"+JSON.stringify(res));
            payHandle_cancel = true;
          });

          // 启动页面再激活监听
          document.addEventListener("resume", function resumeListener() {
            // alert('resume payHandle_cancel:'+payHandle_cancel+' payHandle_success:'+payHandle_success);
            setTimeout(function () {
              if (!payHandle_success) {
                orderCheck(res.data.object.orders.code);// 订单校验
              }
            }, 1000);
            document.removeEventListener("resume", resumeListener);// 删除当前事件监听
          }, false);
        }
      });
    }

    function toShop() {
      $state.go('menu.product');
    }

    /**
     * 分享软件
     */
    function shareApp_wuli() {
      // $httpFactory.sys.config('shareApp').then(function (response) {
      //   shareApp_handle(response);
      // });

      shareApp_handle();
      function shareApp_handle() {

        $scope.popup = {
          params: {
            "title": "从此搞定初中科学",
            "description": "从来没有一款可以如此生动有趣的帮助大家学习初中科学的APP.",
            "thumb": "http://kexue.saixueba.com/wosaiIntro/images/saixueba.png",
            "url": "http://kexue.saixueba.com/wosaiIntro/download.html?v1"
          },
          items: [
            {img: 'img/icon/qzone.png', name: 'QQ空间'},
            {img: 'img/icon/wechatTimeline.png', name: '朋友圈'},]
        }
        $scope.popup.func = f_share;

        $scope.myPopup = $ionicPopup.show({
          cssClass: 'myPopup',
          templateUrl: 'app/share/shareApp.html',
          scope: $scope
        });

        function f_share(item, params) {
          switch (item.name) {
            case 'QQ空间':
              window.share.qq.shareToQzone(params.title, params.description, params.thumb, params.url).then(success, fail);

              // window.share.qq.installed().then(function (isInstalled) {
              //   if (1 === isInstalled || !!isInstalled) {
              //     window.share.qq.shareToQzone(params.title, params.description, params.thumb, params.url).then(success, fail);
              //   } else {
              //     $ionicLoading.show({template: "未安装应用"});
              //   }
              // })
              return true;
            case '朋友圈':
              window.share.wechat.shareTimeLine(params.title, params.description, params.thumb, params.url).then(success, fail);

              // window.share.wechat.installed().then(function (isInstalled) {
              //   if (1 === isInstalled || !!isInstalled) {
              //     window.share.wechat.shareTimeLine(params.title, params.description, params.thumb, params.url).then(success, fail);
              //   } else {
              //     $ionicLoading.show({template: "未安装应用"});
              //   }
              // })
              return true;
          }

          function success(response) {
            console.log('分享成功', response);
          }

          function fail(failResponse) {
            console.log('分享失败', failResponse);
          }
        }

      }
    }

    function shareApp() {
      $httpFactory.sys.sysConfig('shareApp').then(function (res) {
        if (res.data.result == 0) {
          var shareInfo = JSON.parse(res.data.object[0].value);

          // 替换邀请码
          var inviteCode = _appv.currentUser.inviteCode ? _appv.currentUser.inviteCode : '';
          shareInfo.params.title = shareInfo.params.title.replace('{{inviteCode}}', inviteCode);
          shareInfo.params.description = shareInfo.params.description.replace('{{inviteCode}}', inviteCode);

          shareApp_action(shareInfo.params);
        } else {
          $ionicLoading.show({template: '没有获取到分享信息，请稍后再试'});
        }
      })
    }

    function shareApp_action(params) {

      // var params = {
      //   "title": "从此搞定初中科学",
      //   "description": "从来没有一款可以如此生动有趣的帮助大家学习初中科学的APP.",
      //   "thumb": "http://kexue.saixueba.com/wosaiIntro/images/saixueba.png",
      //   "url": "http://kexue.saixueba.com/wosaiIntro/download.html?v1"
      // }
      // var params = _config.platform.share[_config.platform.code];// 备份

      $scope.sharePopup = $ionicPopup.show({
        cssClass: 'myPopup',
        templateUrl: 'app/share/share_com.html',
        scope: $scope
      });

      $scope.share = function (type) {
        // success();
        // return;

        switch (type) {
          case _app.shareType_wechat:
            window.share.wechat.share(params.title, params.description, params.thumb, params.url).then(success, fail);
            return true;
          case _app.shareType_timeLine:
            window.share.wechat.shareTimeLine(params.title, params.description, params.thumb, params.url).then(success, fail);
            return true;
          case _app.shareType_qq:
            window.share.qq.share(params.title, params.description, params.thumb, params.url).then(success, fail);
            return true;
          case _app.shareType_qzone:
            window.share.qq.shareToQzone(params.title, params.description, params.thumb, params.url).then(success, fail);
            return true;
        }
      }

      function success(response) {
        var userId = _appv.currentUser.userId;
        var productCode = $scope.productPay.content[0].productCode;
        $httpFactory.order.productShare(userId, productCode).then(function (response) {
          response.data && $ionicLoading.show({template: response.data.message, duration: 3000});
          $scope.sharePopup.close();
          afterPay();
        }, function (response) {
          response.data && $ionicLoading.show({template: response.data.message, duration: 3000});
        })
      }

      function fail(failResponse) {
        console.log('分享失败', failResponse);
      }

    }

  }
})();
